"""A collection of useful tools

This module includes some personal collection of useful tools.
It is not designed for production usage. Use it at your own risk.
"""
from . import ysdlog

__version__ = "0.1.0"
__all__ = ["ysdlog"]



import logging

logging.basicConfig(
    level=logging.DEBUG,
    format="%(asctime)s | %(name)s | %(levelname)s | %(message)s",
)


def get_logger(name: str):
    """
    Get a simple logger

    Args:
        name(str): A name for logger

    Returns:
        A default logger

    """
    return logging.getLogger(name)


if __name__ == "__main__":
    logger = get_logger("ysdlog")
    logger.debug("start logging...")
